# Модуль для просмотра ВАХ

PyQt-виджет для отображения ВАХ. Предназначен в первую очередь для встраивания в разные продукты линейки EyePoint. Виджет должен уметь выводить несколько ВАХ на график и при необходимости обновлять их.

## Запуск в Windows

1. Установите зависимости:

   ```bash
   python -m venv venv
   venv\Scripts\python -m pip install --upgrade pip
   venv\Scripts\python -m pip install -r requirements.txt
   ```

2. Запустите пример:

   ```bash
   venv\Scripts\python -m ivviewer
   ```

3. Запустите тест:

   ```bash
   testall.bat
   ```

## Запуск в Linux

1. Установите зависимости:

   ```bash
   python3 -m venv venv
   venv/bin/python3 -m pip install --upgrade pip
   venv/bin/python3 -m pip install -r requirements.txt
   ```

2. Запустите пример:

   ```bash
   venv/bin/python3 -m ivviewer
   ```

3. Запустите тест:

   ```bash
   bash testall.sh
   ```

# Выпуск релиза на PyPI

1. Поставьте следующие значения в переменные окружения:

   ```
   TWINE_USERNAME=__token__
   TWINE_PASSWORD=<токен от pypi вместе с префиксом pypi->
   ```
2. Запустите release.sh/release.bat в зависимости от ОС.


Распространенные проблемы с использованием скрипта release:

- Если возникла ошибка `AttributeError: version_info object has no attribute '__version__'`: версия Python на вашем компьютере устарела и не поддерживает twine и build, необходимые для работы с pypi. Поставьте более актуальную версию и добавьте её в путь.
- Если возникла ошибка 403: вы неправильно ввели токен. Проверьте, что вы не потеряли префикс, без него авторизация не будет выполнена.
- Если возникла ошибка 400: вы уже загрузили в репозиторий версию с этим номером. К сожалению, pypi больше не поддерживает замену файлов. Вы можете использовать нумерацию v.v.v-1, v.v.v-2 и т. д. (не рекомендуется) либо загрузить файл как патч со следующим номером версии.


## Примечания

- Модуль тестировался на Python версии 3.6.
- В системе должны быть установлены Qt5, Qwt.
